//******************************************************************************
//   MSP430G2xx3 Demo - USCI_A0, 9600 UART Echo ISR, DCO SMCLK
//
//   Description: Echo a received character, RX ISR used. Normal mode is LPM0.
//   USCI_A0 RX interrupt triggers TX Echo.
//   Baud rate divider with 1MHz = 1MHz/9600 = ~104.2
//   ACLK = n/a, MCLK = SMCLK = CALxxx_1MHZ = 1MHz
//
//                MSP430G2xx3
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |     P1.2/UCA0TXD|------------>
//            |                 | 9600 - 8N1
//            |     P1.1/UCA0RXD|<------------
//
//   D. Dang
//   Texas Instruments Inc.
//   February 2011
//   Built with CCS Version 4.2.0 and IAR Embedded Workbench Version: 5.10
//******************************************************************************

#include "msp430g2553.h"
#include "12864ser.h"
#include "uart.h"
#include "Keyboard.h"
#include "head.h"
//------------------------------------------------------------------------------
// Global variables used for full-duplex UART communication
//------------------------------------------------------------------------------
unsigned char Rx_Byte='0';
unsigned char Rx_flag=0;
float testdata=0.635;

void put_char(unsigned char c)
{
    while (!(IFG2&UCA0TXIFG));                // USCI_A0 TX buffer ready?
    UCA0TXBUF = c;                            // C-> UCA0TXBUF
}

void put_string(unsigned char *str)
{
    while (*str)                                //*str>0x20
    {
        while (!(IFG2&UCA0TXIFG));                // USCI_A0 TX buffer ready?
        UCA0TXBUF = *(str++);                     // *(str++) -> UCA0TXBUF
    }                  
}

unsigned char get_char(void)
{
    Rx_flag=0;
    while (!Rx_flag);                          // USCI_A0 RX buffer ready?
    return UCA0RXBUF;                          // UCA0RXBUF -> char   
}

unsigned char get_key(void)
{
    return Rx_Byte;
}

void put_float(float x,int n)       //xΪҪʾĸݣnΪСλ
{
    unsigned char i=1,j=0,k=0;
    int array[10];
    while(x>=10.0)                  //Сλ   
    {   
        i++;   
        x/=10;   
    }   
    for(j=0;j<n+i+1;j++)            //Сռ1λ   
    {   
       if(j==i)   
       {   
          array[i]=-2;                //248=46ΪСascii   
          continue;   
       }   
       array[j]=(int)x;   
       x-=array[j];   
       x*=10.0;   
    }
    for(k=0;k<n+i+1;k++)
        put_char(array[k]+'0');
    put_char('\r');
    put_char('\n');
}





void get_string(unsigned char *str,unsigned char num)
{
    while(num--)
    {
        Rx_flag=0;
        while (!Rx_flag);                     // USCI_A0 RX buffer ready?
            *(str++) = UCA0RXBUF;             // UCA0RXBUF -> *(str++)
    }                          
}

void Uart_int(void)
{
    P1SEL = BIT1 + BIT2 ;                     // P1.1 = RXD, P1.2=TXD
    P1SEL2 = BIT1 + BIT2;                      
    UCA0CTL1 |= UCSSEL_2;                     // CLK = SMCLK
    UCA0BR0 = 0x41;                            // 1MHz/9600 = ~104.2
    UCA0BR1 = 0x03;
    UCA0MCTL = UCBRS1+UCBRS0 ;                // Modulation UCBRSx = 3
    UCA0CTL1 &= ~UCSWRST;                     // **Initialize USCI state machine**
    IE2 |= UCA0RXIE;                          // Enable USCI_A0 RX interrupt
    __bis_SR_register(GIE);                   //interrupts enabled
}

void Uart_test(void)
{
    Uart_int();
    put_string("Hello World\r\n");
    put_string("READY.\r\n");
}

// USCI A0/B0 Transmit ISR
#pragma vector=USCIAB0TX_VECTOR
__interrupt void USCI0TX_ISR(void)
{
    __bis_SR_register(GIE);
}

// USCI A0/B0 Receive ISR
#pragma vector=USCIAB0RX_VECTOR
__interrupt void USCI0RX_ISR(void)
{
    //__bic_SR_register(GIE);                 //interrupts disabled
    Rx_flag=1;
    while (!(IFG2&UCA0TXIFG));                // USCI_A0 TX buffer ready?
    Rx_Byte = UCA0RXBUF;
    testdata=  recieve_key(Rx_Byte);     //յİַת
    D_A(testdata);
}
